KeyNodeCell

Struct KeyNodeCell 

pub struct KeyNodeCell {
Show 23 fields pub flags: u16, pub last_written_timestamp: u64, pub access_bits: u32, pub parent: u32, pub number_subkeys: u32, pub number_volatile_subkeys: u32, pub subkeys_list_offset: u32, pub volatile_subkeys_list_offset: u32, pub number_key_values: u32, pub key_values_list_offset: u32, pub key_security_offset: u32, pub class_name_offset: u32, pub largest_subkey_class_name_length: u32, pub largest_subkey_name_length: u16, pub virt_and_user_flags: u8, pub debug: u8, pub largest_value_name_length: u32, pub largest_value_data_size: u32, pub work_var: u32, pub key_name_length: u16, pub class_name_length: u16, pub key_name: String, pub offset: u64,
}

Fields

flags: u16

Flags. Bit mask, see below

last_written_timestamp: u64

Last written timestamp. FILETIME (UTC)

access_bits: u32

Access bits. Bit mask, see below (this field is used as of Windows 8 and Windows Server 2012; in previous versions of Windows, this field is reserved and called Spare)

parent: u32

Parent. Offset of a parent key node in bytes, relative from the start of the hive bins data (this field has no meaning on a disk for a root key node)

number_subkeys: u32

Number of subkeys

number_volatile_subkeys: u32

Number of volatile subkeys

subkeys_list_offset: u32

Subkeys list offset. In bytes, relative from the start of the hive bins data (also, this field may point to an Index root)

volatile_subkeys_list_offset: u32

Volatile subkeys list offset. This field has no meaning on a disk (volatile keys are not written to a file)

number_key_values: u32

Number of key values

key_values_list_offset: u32

Key values list offset. In bytes, relative from the start of the hive bins data

key_security_offset: u32

Key security offset. In bytes, relative from the start of the hive bins data

class_name_offset: u32

Class name offset. n bytes, relative from the start of the hive bins data

largest_subkey_class_name_length: u32

Largest subkey class name length. In bytes

largest_subkey_name_length: u16

Largest subkey name length. In bytes, a subkey name is treated as a UTF-16LE string. Starting from Windows Vista, Windows Server 2003 SP2, and Windows XP SP3, the Largest subkey name length field has been split into 4 bit fields

virt_and_user_flags: u8

Virtualization control flags and User flags (Wow64 flags)

debug: u8

Enabling Breakpoints for Registry Keys using the CmpRegDebugBreakEnabled kernel variable

largest_value_name_length: u32

Largest value name length. In bytes, a value name is treated as a UTF-16LE string

largest_value_data_size: u32

Largest value data size. In bytes

work_var: u32

WorkVar. Cached index

key_name_length: u16

Key name length. In bytes

class_name_length: u16

Class name length. In bytes

key_name: String

ASCII (extended) string or UTF-16LE string

offset: u64